==> unixODBC-1.8.4.tar.gz: unixODBC-1.8.4/DataManager/mclassCanvas.cpp <==
/****************************************************************************
** classCanvas meta object code from reading C++ file 'classCanvas.h'
**
** Created: Mon Dec 6 15:49:56 1999
**      by: The Qt Meta Object Compiler ($Revision: 1.2 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#define Q_MOC_classCanvas
#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 3
#elif Q_MOC_OUTPUT_REVISION != 3
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "classCanvas.h"
#include <qmetaobject.h>
#include <qapplication.h>

#if defined(Q_SPARCWORKS_FUNCP_BUG)
#define Q_AMPERSAND
#else
#define Q_AMPERSAND &
#endif


const char *classCanvas::className() const
{
    return "classCanvas";
}

QMetaObject *classCanvas::metaObj = 0;


#if QT_VERSION >= 199
static QMetaObjectInit init_classCanvas(&classCanvas::staticMetaObject);

#endif

void classCanvas::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QLabel::className(), "QLabel") != 0 )
	badSuperclassWarning("classCanvas","QLabel");

#if QT_VERSION >= 199
    staticMetaObject();
}

QString classCanvas::tr(const char* s)
{
    return ((QNonBaseApplication*)qApp)->translate("classCanvas",s);
}

void classCanvas::staticMetaObject()
{
    if ( metaObj )
	return;
    QLabel::staticMetaObject();
#else

    QLabel::initMetaObject();
#endif

    typedef void(classCanvas::*m2_t0)(int,int);
    m2_t0 v2_0 = Q_AMPERSAND classCanvas::changedSize;
    QMetaData *signal_tbl = QMetaObject::new_metadata(1);
    signal_tbl[0].name = "changedSize(int,int)";
    signal_tbl[0].ptr = *((QMember*)&v2_0);
    metaObj = QMetaObject::new_metaobject(
	"classCanvas", "QLabel",
	0, 0,
	signal_tbl, 1 );
}

#include <qobjectdefs.h>
#include <qsignalslotimp.h>

// SIGNAL changedSize
void classCanvas::changedSize( int t0, int t1 )
{
    // No builtin function for signal parameter type int,int
    QConnectionList *clist = receivers("changedSize(int,int)");
    if ( !clist || signalsBlocked() )
	return;
    typedef void (QObject::*RT0)();
    typedef RT0 *PRT0;
    typedef void (QObject::*RT1)(int);
    typedef RT1 *PRT1;
    typedef void (QObject::*RT2)(int,int);
    typedef RT2 *PRT2;
    RT0 r0;
    RT1 r1;
    RT2 r2;
    QConnectionListIt it(*clist);
    QConnection   *c;
    QSenderObject *object;
    while ( (c=it.current()) ) {
	++it;
	object = (QSenderObject*)c->object();
	object->setSender( this );
	switch ( c->numArgs() ) {
	    case 0:
		r0 = *((PRT0)(c->member()));
		(object->*r0)();
		break;
	    case 1:
		r1 = *((PRT1)(c->member()));
		(object->*r1)(t0);
		break;
	    case 2:
		r2 = *((PRT2)(c->member()));
		(object->*r2)(t0, t1);
		break;
	}
    }
}

==> unixODBC-2.0.5.tar.gz: unixODBC-2.0.5/DataManager/mclassCanvas.cpp <==
/****************************************************************************
** classCanvas meta object code from reading C++ file 'classCanvas.h'
**
** Created: Sun Dec 3 14:20:42 2000
**      by: The Qt MOC ($Id: mclassCanvas.cpp,v 1.4 2000/12/04 06:37:09 pharvey Exp $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#define Q_MOC_classCanvas
#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 9
#elif Q_MOC_OUTPUT_REVISION != 9
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "classCanvas.h"
#include <qmetaobject.h>
#include <qapplication.h>

#if defined(Q_SPARCWORKS_FUNCP_BUG)
#define Q_AMPERSAND
#else
#define Q_AMPERSAND &
#endif


const char *classCanvas::className() const
{
    return "classCanvas";
}

QMetaObject *classCanvas::metaObj = 0;

void classCanvas::initMetaObject()
{
    if ( metaObj )
	return;
    if ( qstrcmp(QLabel::className(), "QLabel") != 0 )
	badSuperclassWarning("classCanvas","QLabel");
    (void) staticMetaObject();
}

#ifndef QT_NO_TRANSLATION

QString classCanvas::tr(const char* s)
{
    return qApp->translate( "classCanvas", s, 0 );
}

QString classCanvas::tr(const char* s, const char * c)
{
    return qApp->translate( "classCanvas", s, c );
}

#endif // QT_NO_TRANSLATION

QMetaObject* classCanvas::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    (void) QLabel::staticMetaObject();
#ifndef QT_NO_PROPERTIES
#endif // QT_NO_PROPERTIES
    QMetaData::Access *slot_tbl_access = 0;
    typedef void(classCanvas::*m2_t0)(int,int);
    m2_t0 v2_0 = Q_AMPERSAND classCanvas::changedSize;
    QMetaData *signal_tbl = QMetaObject::new_metadata(1);
    signal_tbl[0].name = "changedSize(int,int)";
    signal_tbl[0].ptr = (QMember)v2_0;
    metaObj = QMetaObject::new_metaobject(
	"classCanvas", "QLabel",
	0, 0,
	signal_tbl, 1,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    metaObj->set_slot_access( slot_tbl_access );
#ifndef QT_NO_PROPERTIES
#endif // QT_NO_PROPERTIES
    return metaObj;
}

#include <qobjectdefs.h>
#include <qsignalslotimp.h>

// SIGNAL changedSize
void classCanvas::changedSize( int t0, int t1 )
{
    // No builtin function for signal parameter type int,int
    QConnectionList *clist = receivers("changedSize(int,int)");
    if ( !clist || signalsBlocked() )
	return;
    typedef void (QObject::*RT0)();
    typedef void (QObject::*RT1)(int);
    typedef void (QObject::*RT2)(int,int);
    RT0 r0;
    RT1 r1;
    RT2 r2;
    QConnectionListIt it(*clist);
    QConnection   *c;
    QSenderObject *object;
    while ( (c=it.current()) ) {
	++it;
	object = (QSenderObject*)c->object();
	object->setSender( this );
	switch ( c->numArgs() ) {
	    case 0:
#ifdef Q_FP_CCAST_BROKEN
		r0 = reinterpret_cast<RT0>(*(c->member()));
#else
		r0 = (RT0)*(c->member());
#endif
		(object->*r0)();
		break;
	    case 1:
#ifdef Q_FP_CCAST_BROKEN
		r1 = reinterpret_cast<RT1>(*(c->member()));
#else
		r1 = (RT1)*(c->member());
#endif
		(object->*r1)(t0);
		break;
	    case 2:
#ifdef Q_FP_CCAST_BROKEN
		r2 = reinterpret_cast<RT2>(*(c->member()));
#else
		r2 = (RT2)*(c->member());
#endif
		(object->*r2)(t0, t1);
		break;
	}
    }
}
